Crate confgr_core

source ·

Enums

  • Shared error type for configuration-related errors.

Traits

  • Provides a unified approach to load configurations from environment variables, files, and default settings. This trait is typically derived using a macro to automate implementations based on struct field names and annotations.
  • Creates an empty configuration layer, used to initialize all None’s, instead of Default.
  • Deserializes a configuration layer from environment variables.
  • Deserializes a configuration layer from a file.
  • Merges configuration layers. Self takes precedence over other.